@@ -5,19 +5,19 @@ use warnings;
 use bytes;
 require Exporter ;
 
-use IO::Compress::Base 2.072 ;
+use IO::Compress::Base 2.073 ;
 
-use IO::Compress::Base::Common  2.072 qw();
-use IO::Compress::Adapter::Bzip2 2.072 ;
+use IO::Compress::Base::Common  2.073 qw();
+use IO::Compress::Adapter::Bzip2 2.073 ;
 
 
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $Bzip2Error);
 
-$VERSION = '2.072';
+$VERSION = '2.073';
 $Bzip2Error = '';
 
-@ISA    = qw(Exporter IO::Compress::Base);
+@ISA    = qw(IO::Compress::Base Exporter);
 @EXPORT_OK = qw( $Bzip2Error bzip2 ) ;
 %EXPORT_TAGS = %IO::Compress::Base::EXPORT_TAGS ;
 push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
@@ -51,7 +51,7 @@ sub getExtraParams
 {
     my $self = shift ;
 
-    use IO::Compress::Base::Common  2.072 qw(:Parse);
+    use IO::Compress::Base::Common  2.073 qw(:Parse);
     
     return (  
             'blocksize100k' => [IO::Compress::Base::Common::Parse_unsigned,  1],
