@@ -8,12 +8,12 @@ use bytes;
 
 require Exporter ;
 
-use IO::Compress::RawDeflate 2.072 () ; 
-use IO::Compress::Adapter::Deflate 2.072 ;
+use IO::Compress::RawDeflate 2.073 () ; 
+use IO::Compress::Adapter::Deflate 2.073 ;
 
-use IO::Compress::Base::Common  2.072 qw(:Status );
-use IO::Compress::Gzip::Constants 2.072 ;
-use IO::Compress::Zlib::Extra 2.072 ;
+use IO::Compress::Base::Common  2.073 qw(:Status );
+use IO::Compress::Gzip::Constants 2.073 ;
+use IO::Compress::Zlib::Extra 2.073 ;
 
 BEGIN
 {
@@ -25,10 +25,10 @@ BEGIN
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, %DEFLATE_CONSTANTS, $GzipError);
 
-$VERSION = '2.072';
+$VERSION = '2.073';
 $GzipError = '' ;
 
-@ISA    = qw(Exporter IO::Compress::RawDeflate);
+@ISA    = qw(IO::Compress::RawDeflate Exporter);
 @EXPORT_OK = qw( $GzipError gzip ) ;
 %EXPORT_TAGS = %IO::Compress::RawDeflate::DEFLATE_CONSTANTS ;
 
