@@ -6,18 +6,18 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base 2.072 ;
-use IO::Compress::Base::Common  2.072 qw(:Status );
-use IO::Compress::Adapter::Deflate 2.072 ;
+use IO::Compress::Base 2.073 ;
+use IO::Compress::Base::Common  2.073 qw(:Status );
+use IO::Compress::Adapter::Deflate 2.073 ;
 
 require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %DEFLATE_CONSTANTS, %EXPORT_TAGS, $RawDeflateError);
 
-$VERSION = '2.072';
+$VERSION = '2.073';
 $RawDeflateError = '';
 
-@ISA = qw(Exporter IO::Compress::Base);
+@ISA = qw(IO::Compress::Base Exporter);
 @EXPORT_OK = qw( $RawDeflateError rawdeflate ) ;
 push @EXPORT_OK, @IO::Compress::Adapter::Deflate::EXPORT_OK ;
 
@@ -116,8 +116,8 @@ sub getExtraParams
     return getZlibParams();
 }
 
-use IO::Compress::Base::Common  2.072 qw(:Parse);
-use Compress::Raw::Zlib  2.072 qw(Z_DEFLATED Z_DEFAULT_COMPRESSION Z_DEFAULT_STRATEGY);
+use IO::Compress::Base::Common  2.073 qw(:Parse);
+use Compress::Raw::Zlib  2.073 qw(Z_DEFLATED Z_DEFAULT_COMPRESSION Z_DEFAULT_STRATEGY);
 our %PARAMS = (
             #'method'   => [IO::Compress::Base::Common::Parse_unsigned,  Z_DEFLATED],
             'level'     => [IO::Compress::Base::Common::Parse_signed,    Z_DEFAULT_COMPRESSION],
