@@ -4,30 +4,30 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.072 qw(:Status );
-use IO::Compress::RawDeflate 2.072 ();
-use IO::Compress::Adapter::Deflate 2.072 ;
-use IO::Compress::Adapter::Identity 2.072 ;
-use IO::Compress::Zlib::Extra 2.072 ;
-use IO::Compress::Zip::Constants 2.072 ;
+use IO::Compress::Base::Common  2.073 qw(:Status );
+use IO::Compress::RawDeflate 2.073 ();
+use IO::Compress::Adapter::Deflate 2.073 ;
+use IO::Compress::Adapter::Identity 2.073 ;
+use IO::Compress::Zlib::Extra 2.073 ;
+use IO::Compress::Zip::Constants 2.073 ;
 
 use File::Spec();
 use Config;
 
-use Compress::Raw::Zlib  2.072 (); 
+use Compress::Raw::Zlib  2.073 (); 
 
 BEGIN
 {
     eval { require IO::Compress::Adapter::Bzip2 ; 
-           import  IO::Compress::Adapter::Bzip2 2.072 ; 
+           import  IO::Compress::Adapter::Bzip2 2.073 ; 
            require IO::Compress::Bzip2 ; 
-           import  IO::Compress::Bzip2 2.072 ; 
+           import  IO::Compress::Bzip2 2.073 ; 
          } ;
          
     eval { require IO::Compress::Adapter::Lzma ; 
-           import  IO::Compress::Adapter::Lzma 2.072 ; 
+           import  IO::Compress::Adapter::Lzma 2.073 ; 
            require IO::Compress::Lzma ; 
-           import  IO::Compress::Lzma 2.072 ; 
+           import  IO::Compress::Lzma 2.073 ; 
          } ;
 }
 
@@ -36,10 +36,10 @@ require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, %DEFLATE_CONSTANTS, $ZipError);
 
-$VERSION = '2.072';
+$VERSION = '2.073';
 $ZipError = '';
 
-@ISA = qw(Exporter IO::Compress::RawDeflate);
+@ISA = qw(IO::Compress::RawDeflate Exporter);
 @EXPORT_OK = qw( $ZipError zip ) ;
 %EXPORT_TAGS = %IO::Compress::RawDeflate::DEFLATE_CONSTANTS ;
 
