@@ -4,19 +4,19 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common 2.072 ();
+use IO::Compress::Base::Common 2.073 ();
 
-use IO::Uncompress::Base 2.072 ;
+use IO::Uncompress::Base 2.073 ;
 
 
 require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $AnyUncompressError);
 
-$VERSION = '2.072';
+$VERSION = '2.073';
 $AnyUncompressError = '';
 
-@ISA = qw( Exporter IO::Uncompress::Base );
+@ISA = qw(IO::Uncompress::Base Exporter);
 @EXPORT_OK = qw( $AnyUncompressError anyuncompress ) ;
 %EXPORT_TAGS = %IO::Uncompress::Base::DEFLATE_CONSTANTS ;
 push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
@@ -29,22 +29,22 @@ BEGIN
 {
    local @INC = @INC;
    pop @INC if $INC[-1] eq '.';
-   eval ' use IO::Uncompress::Adapter::Inflate 2.072 ;';
-   eval ' use IO::Uncompress::Adapter::Bunzip2 2.072 ;';
-   eval ' use IO::Uncompress::Adapter::LZO 2.072 ;';
-   eval ' use IO::Uncompress::Adapter::Lzf 2.072 ;';
-   eval ' use IO::Uncompress::Adapter::UnLzma 2.072 ;';
-   eval ' use IO::Uncompress::Adapter::UnXz 2.072 ;';
+   eval ' use IO::Uncompress::Adapter::Inflate 2.073 ;';
+   eval ' use IO::Uncompress::Adapter::Bunzip2 2.073 ;';
+   eval ' use IO::Uncompress::Adapter::LZO 2.073 ;';
+   eval ' use IO::Uncompress::Adapter::Lzf 2.073 ;';
+   eval ' use IO::Uncompress::Adapter::UnLzma 2.073 ;';
+   eval ' use IO::Uncompress::Adapter::UnXz 2.073 ;';
 
-   eval ' use IO::Uncompress::Bunzip2 2.072 ;';
-   eval ' use IO::Uncompress::UnLzop 2.072 ;';
-   eval ' use IO::Uncompress::Gunzip 2.072 ;';
-   eval ' use IO::Uncompress::Inflate 2.072 ;';
-   eval ' use IO::Uncompress::RawInflate 2.072 ;';
-   eval ' use IO::Uncompress::Unzip 2.072 ;';
-   eval ' use IO::Uncompress::UnLzf 2.072 ;';
-   eval ' use IO::Uncompress::UnLzma 2.072 ;';
-   eval ' use IO::Uncompress::UnXz 2.072 ;';
+   eval ' use IO::Uncompress::Bunzip2 2.073 ;';
+   eval ' use IO::Uncompress::UnLzop 2.073 ;';
+   eval ' use IO::Uncompress::Gunzip 2.073 ;';
+   eval ' use IO::Uncompress::Inflate 2.073 ;';
+   eval ' use IO::Uncompress::RawInflate 2.073 ;';
+   eval ' use IO::Uncompress::Unzip 2.073 ;';
+   eval ' use IO::Uncompress::UnLzf 2.073 ;';
+   eval ' use IO::Uncompress::UnLzma 2.073 ;';
+   eval ' use IO::Uncompress::UnXz 2.073 ;';
 }
 
 sub new
