@@ -9,18 +9,18 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Uncompress::RawInflate 2.072 ;
+use IO::Uncompress::RawInflate 2.073 ;
 
-use Compress::Raw::Zlib 2.072 () ;
-use IO::Compress::Base::Common 2.072 qw(:Status );
-use IO::Compress::Gzip::Constants 2.072 ;
-use IO::Compress::Zlib::Extra 2.072 ;
+use Compress::Raw::Zlib 2.073 () ;
+use IO::Compress::Base::Common 2.073 qw(:Status );
+use IO::Compress::Gzip::Constants 2.073 ;
+use IO::Compress::Zlib::Extra 2.073 ;
 
 require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $GunzipError);
 
-@ISA = qw( Exporter IO::Uncompress::RawInflate );
+@ISA = qw(IO::Uncompress::RawInflate Exporter);
 @EXPORT_OK = qw( $GunzipError gunzip );
 %EXPORT_TAGS = %IO::Uncompress::RawInflate::DEFLATE_CONSTANTS ;
 push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
@@ -28,7 +28,7 @@ Exporter::export_ok_tags('all');
 
 $GunzipError = '';
 
-$VERSION = '2.072';
+$VERSION = '2.073';
 
 sub new
 {
